@@ -9,11 +9,12 @@ from ..functions.base import BaseFunction
 from ..properties.constant import Constant
 from ..properties.property import Property
 from ..structures.cast_operator import CastOperator
+from ..structures.case import Case
 
 
 class ConvertTimezone(BaseFunction):
     obj: Literal['functions.ConvertTimezone'] = 'functions.ConvertTimezone'
-    property: Union[Property, BaseFunction, Constant, CastOperator]
+    property: Union[Property, BaseFunction, Constant, CastOperator, Case]
     date_from: Constant
     date_to: Constant
     alias: str = None
