@@ -8,11 +8,12 @@ except ImportError:
 from ..functions.base import BaseFunction
 from ..properties.property import Property
 from ..structures.cast_operator import CastOperator
+from ..structures.case import Case
 
 
 class Sum(BaseFunction):
     obj: Literal['functions.Sum'] = 'functions.Sum'
-    property: Union[Property, BaseFunction, CastOperator]
+    property: Union[Property, BaseFunction, CastOperator, Case]
     alias: str = None
 
     def to_sql(self) -> str:
